@@ -161,6 +161,7 @@ static void mymergesort( int first, int last, Segment **seg )
 	{
 		if( work ) free( work ); 
 		work = NULL;
+		allo = 0;
 		return;
 	}
 
@@ -707,7 +708,7 @@ system( "/usr/bin/gnuplot list.plot" );
 				Aalign( tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen );
 				break;
 			case( 'M' ):
-					MSalignmm( n_dis_consweight_multi, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, headgp, tailgp );
+					MSalignmm( n_dynamicmtx, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, headgp, tailgp );
 				break;
 			case( 'A' ):
 				if( clus1 == 1 && clus2 == 1 )
@@ -715,18 +716,6 @@ system( "/usr/bin/gnuplot list.plot" );
 				else
 					A__align( n_dynamicmtx, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, headgp, tailgp );
 				break;
-			case( 'H' ):
-				if( clus1 == 1 && clus2 == 1 )
-					G__align11( n_dynamicmtx, tmpres1, tmpres2, alloclen, headgp, tailgp );
-				else
-					H__align( tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-				break;
-			case( 'Q' ):
-				if( clus1 == 1 && clus2 == 1 )
-					G__align11( n_dynamicmtx, tmpres1, tmpres2, alloclen, headgp, tailgp );
-				else
-					Q__align( tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-				break;
 			default:
 				fprintf( stderr, "alg = %c\n", alg );
 				ErrorExit( "ERROR IN SOURCE FILE Falign.c" );
@@ -831,6 +820,8 @@ float Falign( double **offsetmtx, double ***scoringmatrices, double **n_dynamicm
 		{
 //			fprintf( stderr, "Freeing localarrays in Falign\n" );
 			localalloclen = 0;
+			prevalloclen = 0;
+			crossscoresize = 0;
 			mymergesort( 0, 0, NULL );
 			alignableReagion( 0, 0, NULL, NULL, NULL, NULL, NULL );
 			fft( 0, NULL, 1 );
@@ -839,6 +830,7 @@ float Falign( double **offsetmtx, double ***scoringmatrices, double **n_dynamicm
 			G__align11( NULL, NULL, NULL, 0, 0, 0 );
 			blockAlign2( NULL, NULL, NULL, NULL, NULL, NULL );
 			if( crossscore ) FreeDoubleMtx( crossscore );
+			crossscore = NULL;
 			FreeCharMtx( result1 ); result1 = NULL;
 			FreeCharMtx( result2 );
 			FreeCharMtx( tmpres1 );
@@ -1530,27 +1522,13 @@ system( "less seqVec2 < /dev/tty > /dev/tty" );
 				else
 				{
 					if( scoringmatrices ) // called by tditeration.c
+					{
 						totalscore += A__align_variousdist( NULL, scoringmatrices, NULL, tmpres1, tmpres2, eff1, eff2, eff1s, eff2s, clus1, clus2, alloclen, NULL, &dumfl, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
+					}
 					else
 						totalscore += A__align( n_dynamicmtx, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumfl, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
 				}
 				break;
-			case( 'H' ):
-				if( clus1 == 1 && clus2 == 1 )
-				{
-					totalscore += G__align11( n_dynamicmtx, tmpres1, tmpres2, alloclen, headgp, tailgp );
-				}
-				else
-					totalscore += H__align( tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumfl, sgap1, sgap2, egap1, egap2 );
-				break;
-			case( 'Q' ):
-				if( clus1 == 1 && clus2 == 1 )
-				{
-					totalscore += G__align11( n_dynamicmtx, tmpres1, tmpres2, alloclen, headgp, tailgp );
-				}
-				else
-					totalscore += Q__align( tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumfl, sgap1, sgap2, egap1, egap2 );
-				break;
 			default:
 				fprintf( stderr, "alg = %c\n", alg );
 				ErrorExit( "ERROR IN SOURCE FILE Falign.c" );
@@ -1677,6 +1655,8 @@ float Falign_udpari_long(
 		{
 //			fprintf( stderr, "### Freeing localarrays in Falign\n" );
 			localalloclen = 0;
+			prevalloclen = 0;
+			crossscoresize = 0;
 			mymergesort( 0, 0, NULL );
 			alignableReagion( 0, 0, NULL, NULL, NULL, NULL, NULL );
 			fft( 0, NULL, 1 );
