@@ -14,6 +14,7 @@ static int distout;
 static int noalign;
 static int multidist;
 static int maxdist = 2; // scale -> 2bai
+static int allowlongadds;
 
 static float lenfaca, lenfacb, lenfacc, lenfacd;
 static int tuplesize;
@@ -829,6 +830,7 @@ void arguments( int argc, char *argv[] )
 	kobetsubunkatsu = 0;
 	dorp = NOTSPECIFIED;
 	ppenalty = NOTSPECIFIED;
+	penalty_shift_factor = 1000.0;
 	ppenalty_ex = NOTSPECIFIED;
 	poffset = NOTSPECIFIED;
 	kimuraR = NOTSPECIFIED;
@@ -846,6 +848,7 @@ void arguments( int argc, char *argv[] )
 	multidist = 0;
 	tuplesize = -1;
 	legacygapcost = 0;
+	allowlongadds = 0;
 
     while( --argc > 0 && (*++argv)[0] == '-' )
 	{
@@ -876,6 +879,10 @@ void arguments( int argc, char *argv[] )
 //					fprintf( stderr, "ppenalty = %d\n", ppenalty );
 					--argc;
 					goto nextoption;
+				case 'Q':
+					penalty_shift_factor = atof( *++argv );
+					--argc;
+					goto nextoption;
 				case 'g':
 					ppenalty_ex = (int)( atof( *++argv ) * 1000 - 0.5 );
 					fprintf( stderr, "ppenalty_ex = %d\n", ppenalty_ex );
@@ -1001,10 +1008,10 @@ void arguments( int argc, char *argv[] )
 				case 'a':
 					alg = 'a';
 					break;
-#endif
 				case 'Q':
 					alg = 'Q';
 					break;
+#endif
 				case 'H':
 					alg = 'H';
 					break;
@@ -1029,9 +1036,14 @@ void arguments( int argc, char *argv[] )
 				case 'U':
 					treein = 1;
 					break;
+				case 'V':
+					allowlongadds = 1;
+					break;
+#if 0
 				case 'V':
 					topin = 1;
 					break;
+#endif
 				case 'u':
 					tbrweight = 0;
 					weight = 0;
@@ -1350,21 +1362,10 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
 				pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
-			else if( alg == 'H' )
-			{
-				imp_match_init_strictH( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-				pscore = H__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL );
-			}
 			else if( alg == 'Q' )
 			{
-				imp_match_init_strictQ( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-				if( rnakozo ) imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
-				pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL );
-			}
-			else if( alg == 'R' )
-			{
-				imp_match_init_strictR( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-				pscore = R__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL );
+				fprintf( stderr, "Q has been disabled.\n" );
+				exit( 1 );
 			}
 		}
 		else if( force_fft || ( use_fft && ffttry ) )
@@ -1394,15 +1395,6 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 				case( 'A' ):
 					pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
-				case( 'Q' ):
-					pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-					break;
-				case( 'R' ):
-					pscore = R__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-					break;
-				case( 'H' ):
-					pscore = H__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-					break;
 				default:
 					ErrorExit( "ERROR IN SOURCE FILE" );
 			}
@@ -1479,6 +1471,7 @@ static float treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeor
 	}
 	free( effarr1_kozo );
 	free( effarr2_kozo );
+
 	return( pscore );
 }
 
@@ -1523,8 +1516,10 @@ static void	*addsinglethread( void *arg )
 		int *addmem;
 		int njobc, norg;
 		char **bseq;
-		int i, j, iadd, rep, neighbor;
+		int i, j, k, m, iadd, rep, neighbor;
 		char *mergeoralign;
+		int *nogaplenjusttodecideaddhereornot;
+		char *tmpseq;
 
 #ifdef enablemultithread
 		int thread_no = targ->thread_no;
@@ -1549,12 +1544,14 @@ static void	*addsinglethread( void *arg )
 		float **len = targ->len;
 		Addtree *addtree = targ->addtree;
 		float pscore;
+		int *alnleninnode;
 
 
 //		fprintf( stderr, "\nPreparing thread %d\n", thread_no );
 		norg = njob - nadd;
 		njobc = norg+1;
 
+		alnleninnode = AllocateIntVec( norg );
 		addmem = AllocateIntVec( nadd+1 );
 		depc = (Treedep *)calloc( njobc, sizeof( Treedep ) );
 		mseq1 = AllocateCharMtx( njob, 0 );
@@ -1563,6 +1560,54 @@ static void	*addsinglethread( void *arg )
 		namec = AllocateCharMtx( njob, 0 );
 		nlenc = AllocateIntVec( njob );
 		mergeoralign = AllocateCharVec( njob );
+		nogaplenjusttodecideaddhereornot = AllocateIntVec( njob );
+		tmpseq = calloc( alloclen, sizeof( char ) );
+
+		if( allowlongadds )
+		{
+			for( i=0; i<njob; i++ ) nogaplenjusttodecideaddhereornot[i] = 0;
+		}
+		else
+		{
+			for( i=0; i<njob; i++ ) 
+			{
+				gappick0( tmpseq, seq[i] );
+				nogaplenjusttodecideaddhereornot[i] = strlen( tmpseq );
+			}
+		}
+
+		for( i=0; i<norg; i++ ) strcpy( bseq[i], seq[i] );
+		if( norg == 1 )
+		{
+			alnleninnode[0] = strlen( bseq[0] );
+		}
+		else
+		{
+			for( i=norg-2; i>=0; i-- ) 
+//			for( i=norg-2; i; i-- )  // BUG!!!!
+			{
+//				reporterr( "\nstep %d\n", i );
+				k = 0;
+				for( j=0; (m=topol[i][0][j])!=-1; j++ ) 
+				{
+					mseq1[k++] = bseq[m];
+//					reporterr( "%d ", m );
+				}
+				for( j=0; (m=topol[i][1][j])!=-1; j++ ) 
+				{
+					mseq1[k++] = bseq[m];
+//					reporterr( "%d ", m );
+				}
+//				reporterr( "\n" );
+				commongappick( k, mseq1 );
+				alnleninnode[i] = strlen( mseq1[0] );
+//				fprintf( stderr, "alnleninnode[%d] = %d\n", i, alnleninnode[i] );
+			}
+		}
+//		for( i=0; i<norg-1; i++ )
+//			fprintf( stderr, "alnleninnode[%d] = %d\n", i, alnleninnode[i] );
+
+
 		if( constraint )
 		{
 			localhomtablec = (LocalHom **)calloc( njobc, sizeof( LocalHom *) ); // motto chiisaku dekiru.
@@ -1676,7 +1721,7 @@ static void	*addsinglethread( void *arg )
 //			{
 //			}
 //			fixed_musclesupg_float_realloc_nobk_halfmtx( njobc, iscorec, topolc, lenc, depc, 0 );
-			neighbor = addonetip( njobc, topolc, lenc, iscorec, topol, len, dep, treeout, addtree, iadd, name );
+			neighbor = addonetip( njobc, topolc, lenc, iscorec, topol, len, dep, treeout, addtree, iadd, name, alnleninnode, nogaplenjusttodecideaddhereornot );
 
 			if( noalign ) 
 			{
@@ -1700,11 +1745,14 @@ static void	*addsinglethread( void *arg )
 #if 0
 			for( i=0; i<njobc-1; i++ )
 			{
+				fprintf( stderr, "\n step %d\n", i );
 				fprintf( stderr, "topol[%d] = \n", i );
 				for( j=0; topolc[i][0][j]!=-1; j++ ) fprintf( stderr, "%d ", topolc[i][0][j] );
 				fprintf( stderr, "\n" );
+				fprintf( stderr, "len=%f\n", lenc [i][0] );
 				for( j=0; topolc[i][1][j]!=-1; j++ ) fprintf( stderr, "%d ", topolc[i][1][j] );
 				fprintf( stderr, "\n" );
+				fprintf( stderr, "len=%f\n", lenc [i][1] );
 			}
 
 			fprintf( stderr, "\nneighbor = %d, iadd = %d\n", neighbor, iadd );
@@ -1830,6 +1878,9 @@ static void	*addsinglethread( void *arg )
 			free( localhomtablec );
 		}
 		free( mergeoralign );
+		free( nogaplenjusttodecideaddhereornot );
+		free( alnleninnode );
+		free( tmpseq );
 		FreeCharMtx( bseq );
 		free( namec );
 		free( nlenc  );
@@ -2345,7 +2396,7 @@ void ktupledistancematrix( int nseq, int norg, int nlenmax, char **seq, char **n
 		}
 
 	}
-	if( nunknown ) fprintf( stderr, "\nWARNING : %d unknown characters\n", nunknown );
+	if( nunknown ) fprintf( stderr, "\nThere are %d ambiguous characters\n", nunknown );
 
 	for( i=0; i<nseq; i++ ) // serial de jubun
 	{
