@@ -91,14 +91,14 @@ static void calcfreq_nuc( int nseq, char **seq, double *datafreq )
 
 
 	total = 0.0; for( i=0; i<4; i++ ) total += datafreq[i];
-//	fprintf( stderr, "total = %f\n", total );
+//	reporterr(       "total = %f\n", total );
 	for( i=0; i<4; i++ ) datafreq[i] /= (double)total;
 
 #if 0
-	fprintf( stderr, "\ndatafreq = " );
+	reporterr(       "\ndatafreq = " );
 	for( i=0; i<4; i++ )
-		fprintf( stderr, "%10.5f ", datafreq[i] );
-	fprintf( stderr, "\n" );
+		reporterr(       "%10.5f ", datafreq[i] );
+	reporterr(       "\n" );
 	exit( 1 );
 #endif
 }
@@ -128,12 +128,12 @@ static void calcfreq( int nseq, char **seq, double *datafreq )
 	for( i=0; i<nscoredalphabets; i++ ) datafreq[i] /= (double)total;
 	for( i=0; i<nscoredalphabets; i++ ) if( datafreq[i] < 0.0001 ) datafreq[i] = 0.0001;
 
-//	fprintf( stderr, "datafreq = \n" );
+//	reporterr(       "datafreq = \n" );
 //	for( i=0; i<nscoredalphabets; i++ )
-//		fprintf( stderr, "%f\n", datafreq[i] );
+//		reporterr(       "%f\n", datafreq[i] );
 
 	total = 0.0; for( i=0; i<nscoredalphabets; i++ ) total += datafreq[i];
-//	fprintf( stderr, "total = %f\n", total );
+//	reporterr(       "total = %f\n", total );
 	for( i=0; i<nscoredalphabets; i++ ) datafreq[i] /= (double)total;
 }
 
@@ -168,9 +168,13 @@ void constants( int nseq, char **seq )
 {
 	int i, j, x;
 //	double tmp;
+	char shiftmodel[100];
 
 	if( nblosum < 0 ) dorp = 'p';
 
+	if( penalty_shift_factor >= 10 ) trywarp = 0;
+	else trywarp = 1;
+
 	if( dorp == 'd' )  /* DNA */
 	{
 		int k, m;
@@ -189,6 +193,7 @@ void constants( int nseq, char **seq )
 		if( RNAppenalty == NOTSPECIFIED ) RNAppenalty = DEFAULTRNAGOP_N;
 		if( RNAppenalty_ex == NOTSPECIFIED ) RNAppenalty_ex = DEFAULTRNAGEP_N;
 		if( ppenalty == NOTSPECIFIED ) ppenalty = DEFAULTGOP_N;
+		if( ppenalty_dist == NOTSPECIFIED ) ppenalty_dist = ppenalty;
 		if( ppenalty_OP == NOTSPECIFIED ) ppenalty_OP = DEFAULTGOP_N;
 		if( ppenalty_ex == NOTSPECIFIED ) ppenalty_ex = DEFAULTGEP_N;
 		if( ppenalty_EX == NOTSPECIFIED ) ppenalty_EX = DEFAULTGEP_N;
@@ -199,13 +204,15 @@ void constants( int nseq, char **seq )
 
 		RNApenalty = (int)( 3 * 600.0 / 1000.0 * RNAppenalty + 0.5 );
 		RNApenalty_ex = (int)( 3 * 600.0 / 1000.0 * RNAppenalty_ex + 0.5 );
-//		fprintf( stderr, "DEFAULTRNAGOP_N = %d\n", DEFAULTRNAGOP_N );
-//		fprintf( stderr, "RNAppenalty = %d\n", RNAppenalty );
-//		fprintf( stderr, "RNApenalty = %d\n", RNApenalty );
+//		reporterr(       "DEFAULTRNAGOP_N = %d\n", DEFAULTRNAGOP_N );
+//		reporterr(       "RNAppenalty = %d\n", RNAppenalty );
+//		reporterr(       "RNApenalty = %d\n", RNApenalty );
 
 
 		RNAthr = (int)( 3 * 600.0 / 1000.0 * RNApthr + 0.5 );
 		penalty = (int)( 3 * 600.0 / 1000.0 * ppenalty + 0.5);
+		penalty_dist = (int)( 3 * 600.0 / 1000.0 * ppenalty_dist + 0.5);
+		penalty_shift = (int)( penalty_shift_factor * penalty );
 		penalty_OP = (int)( 3 * 600.0 / 1000.0 * ppenalty_OP + 0.5);
 		penalty_ex = (int)( 3 * 600.0 / 1000.0 * ppenalty_ex + 0.5);
 		penalty_EX = (int)( 3 * 600.0 / 1000.0 * ppenalty_EX + 0.5);
@@ -214,8 +221,11 @@ void constants( int nseq, char **seq )
 		offsetLN = (int)( 1 * 600.0 / 1000.0 * 100 + 0.5);
 		penaltyLN = (int)( 3 * 600.0 / 1000.0 * -2000 + 0.5);
 		penalty_exLN = (int)( 3 * 600.0 / 1000.0 * -100 + 0.5);
-		sprintf( modelname, "%s%d (%d), %6.3f (%6.3f), %6.3f (%6.3f)", rnakozo?"RNA":"DNA", pamN, kimuraR,
-        -(double)ppenalty*0.001, -(double)ppenalty*0.003, -(double)poffset*0.001, -(double)poffset*0.003 );
+
+		if( trywarp ) sprintf( shiftmodel, "%4.2f (%4.2f)", -(double)penalty_shift/1800, -(double)penalty_shift/600 );
+		else sprintf( shiftmodel, "noshift" );
+
+		sprintf( modelname, "%s%d (%d), %4.2f (%4.2f), %4.2f (%4.2f), %s", rnakozo?"RNA":"DNA", pamN, kimuraR, -(double)ppenalty*0.001, -(double)ppenalty*0.003, -(double)poffset*0.001, -(double)poffset*0.003, shiftmodel );
 
 		for( i=0; i<26; i++ ) amino[i] = locaminon[i];
 		for( i=0; i<0x80; i++ ) amino_n[i] = -1;
@@ -223,10 +233,10 @@ void constants( int nseq, char **seq )
 		if( fmodel == 1 )
 		{
 			calcfreq_nuc( nseq, seq, freq );
-			fprintf( stderr, "a, freq[0] = %f\n", freq[0] );
-			fprintf( stderr, "g, freq[1] = %f\n", freq[1] );
-			fprintf( stderr, "c, freq[2] = %f\n", freq[2] );
-			fprintf( stderr, "t, freq[3] = %f\n", freq[3] );
+			reporterr(       "a, freq[0] = %f\n", freq[0] );
+			reporterr(       "g, freq[1] = %f\n", freq[1] );
+			reporterr(       "c, freq[2] = %f\n", freq[2] );
+			reporterr(       "t, freq[3] = %f\n", freq[3] );
 		}
 		else
 		{
@@ -248,7 +258,7 @@ void constants( int nseq, char **seq )
 			average /= 16.0;
 	
    	     if( disp )
-				fprintf( stderr, "average = %f\n", average );
+				reporterr(       "average = %f\n", average );
 	
 			for( i=0; i<4; i++ ) for( j=0; j<4; j++ ) 
 				pamx[i][j] -= average;
@@ -274,18 +284,18 @@ void constants( int nseq, char **seq )
 				generatenuc1pam( pam1, kimuraR, freq );
 #endif
 	
-				fprintf( stderr, "generating %dPAM scoring matrix for nucleotides ... ", pamN );
+				reporterr(       "generating a scoring matrix for nucleotide (dist=%d) ... ", pamN );
 	
 		       	if( disp )
    		    	{
-   		     		fprintf( stderr, " TPM \n" );
+   		     		reporterr(       " TPM \n" );
    		        	for( i=0; i<4; i++ )
    			       	{
    		            	for( j=0; j<4; j++ )
-   		                	fprintf( stderr, "%+#6.10f", pam1[i][j] );
-   		            	fprintf( stderr, "\n" );
+   		                	reporterr(       "%+#6.10f", pam1[i][j] );
+   		            	reporterr(       "\n" );
    		        	}
-   		        	fprintf( stderr, "\n" );
+   		        	reporterr(       "\n" );
    		     	}
 	
 	
@@ -294,14 +304,14 @@ void constants( int nseq, char **seq )
 
 		       	if( disp )
    		    	{
-   		     		fprintf( stderr, " TPM \n" );
+   		     		reporterr(       " TPM \n" );
    		        	for( i=0; i<4; i++ )
    			       	{
    		            	for( j=0; j<4; j++ )
-   		                	fprintf( stderr, "%+#6.10f", pamx[i][j] );
-   		            	fprintf( stderr, "\n" );
+   		                	reporterr(       "%+#6.10f", pamx[i][j] );
+   		            	reporterr(       "\n" );
    		        	}
-   		        	fprintf( stderr, "\n" );
+   		        	reporterr(       "\n" );
    		     	}
 
 				for( i=0; i<4; i++ ) for( j=0; j<4; j++ )
@@ -312,7 +322,7 @@ void constants( int nseq, char **seq )
 				{
 					if( pamx[i][j] == 0.0 ) 
 					{
-						fprintf( stderr, "WARNING: pamx[i][j] = 0.0 ?\n" );
+						reporterr(       "WARNING: pamx[i][j] = 0.0 ?\n" );
 						pamx[i][j] = 0.00001; /* by J. Thompson */
 					}
 					pamx[i][j] = log10( pamx[i][j] ) * 1000.0;
@@ -320,14 +330,14 @@ void constants( int nseq, char **seq )
 	
    	    		if( disp )
    	    		{
-   		     		fprintf( stderr, " after log\n" );
+   		     		reporterr(       " after log\n" );
    	        		for( i=0; i<4; i++ )
    		       		{
    	        	    	for( j=0; j<4; j++ )
-   	        	        	fprintf( stderr, "%+10.6f ", pamx[i][j] );
-   	        	    	fprintf( stderr, "\n" );
+   	        	        	reporterr(       "%+10.6f ", pamx[i][j] );
+   	        	    	reporterr(       "\n" );
    	        		}
-   	        		fprintf( stderr, "\n" );
+   	        		reporterr(       "\n" );
    		     	}
 
 
@@ -355,16 +365,16 @@ void constants( int nseq, char **seq )
 
        		if( disp )
        		{
-        		fprintf( stderr, " after shishagonyuu\n" );
+        		reporterr(       " after shishagonyuu\n" );
            		for( i=0; i<4; i++ )
    	       		{
            	    	for( j=0; j<4; j++ )
-           	        	fprintf( stderr, "%+#6.10f", pamx[i][j] );
-           	    	fprintf( stderr, "\n" );
+           	        	reporterr(       "%+#6.10f", pamx[i][j] );
+           	    	reporterr(       "\n" );
            		}
-           		fprintf( stderr, "\n" );
+           		reporterr(       "\n" );
         	}
-			fprintf( stderr, "done\n" );
+			reporterr(       "done\n" );
 		}
 	
 		for( i=0; i<5; i++ ) 
@@ -380,26 +390,26 @@ void constants( int nseq, char **seq )
 	
        	if( disp )
        	{
-       		fprintf( stderr, " before dis\n" );
+       		reporterr(       " before dis\n" );
           	for( i=0; i<4; i++ )
    	       	{
            	   	for( j=0; j<4; j++ )
-           	       	fprintf( stderr, "%+#6.10f", pamx[i][j] );
-           	   	fprintf( stderr, "\n" );
+           	       	reporterr(       "%+#6.10f", pamx[i][j] );
+           	   	reporterr(       "\n" );
            	}
-           	fprintf( stderr, "\n" );
+           	reporterr(       "\n" );
         }
 
        	if( disp )
        	{
-        	fprintf( stderr, " score matrix  \n" );
+        	reporterr(       " score matrix  \n" );
            	for( i=0; i<4; i++ )
    	       	{
                	for( j=0; j<4; j++ )
-                   	fprintf( stderr, "%+#6.10f", pamx[i][j] );
-               	fprintf( stderr, "\n" );
+                   	reporterr(       "%+#6.10f", pamx[i][j] );
+               	reporterr(       "\n" );
            	}
-           	fprintf( stderr, "\n" );
+           	reporterr(       "\n" );
 					exit( 1 );
         }
 
@@ -412,15 +422,15 @@ void constants( int nseq, char **seq )
 
         if( disp )
         {
-            fprintf( stderr, " score matrix  \n" );
+            reporterr(       " score matrix  \n" );
             for( i=0; i<26; i++ )
             {
                 for( j=0; j<26; j++ )
-                    fprintf( stderr, "%+6d", n_dis[i][j] );
-                fprintf( stderr, "\n" );
+                    reporterr(       "%+6d", n_dis[i][j] );
+                reporterr(       "\n" );
             }
-            fprintf( stderr, "\n" );
-			fprintf( stderr, "penalty = %d, penalty_ex = %d\n", penalty, penalty_ex );
+            reporterr(       "\n" );
+			reporterr(       "penalty = %d, penalty_ex = %d\n", penalty, penalty_ex );
         }
 
 // RIBOSUM
@@ -472,24 +482,24 @@ void constants( int nseq, char **seq )
 
   		if( disp )
    		{
-     		fprintf( stderr, "ribosum after shishagonyuu\n" );
+     		reporterr(       "ribosum after shishagonyuu\n" );
        		for( i=0; i<4; i++ )
        		{
        	    	for( j=0; j<4; j++ )
-       	        	fprintf( stderr, "%+#6.10f", ribosum4[i][j] );
-       	    	fprintf( stderr, "\n" );
+       	        	reporterr(       "%+#6.10f", ribosum4[i][j] );
+       	    	reporterr(       "\n" );
        		}
-       		fprintf( stderr, "\n" );
-     		fprintf( stderr, "ribosum16 after shishagonyuu\n" );
+       		reporterr(       "\n" );
+     		reporterr(       "ribosum16 after shishagonyuu\n" );
        		for( i=0; i<16; i++ )
        		{
        	    	for( j=0; j<16; j++ )
-       	        	fprintf( stderr, "%+#7.0f", ribosum16[i][j] );
-       	    	fprintf( stderr, "\n" );
+       	        	reporterr(       "%+#7.0f", ribosum16[i][j] );
+       	    	reporterr(       "\n" );
        		}
-       		fprintf( stderr, "\n" );
+       		reporterr(       "\n" );
       	}
-		fprintf( stderr, "done\n" );
+		reporterr(       "done\n" );
 
 #if 1
 		for( i=0; i<37; i++ ) for( j=0; j<37; j++ ) ribosumdis[i][j] = 0.0; //iru
@@ -507,16 +517,16 @@ void constants( int nseq, char **seq )
 
   		if( disp )
    		{
-     		fprintf( stderr, "ribosumdis\n" );
+     		reporterr(       "ribosumdis\n" );
        		for( i=0; i<37; i++ )
        		{
        	    	for( j=0; j<37; j++ )
-       	        	fprintf( stderr, "%+5d", ribosumdis[i][j] );
-       	    	fprintf( stderr, "\n" );
+       	        	reporterr(       "%+5d", ribosumdis[i][j] );
+       	    	reporterr(       "\n" );
        		}
-       		fprintf( stderr, "\n" );
+       		reporterr(       "\n" );
       	}
-		fprintf( stderr, "done\n" );
+		reporterr(       "done\n" );
 #endif
 
 		FreeDoubleMtx( pam1 );
@@ -536,7 +546,7 @@ void constants( int nseq, char **seq )
 		nalphabets = 0x80;
 		nscoredalphabets = 0x80;
 
-		fprintf( stderr, "nalphabets = %d\n", nalphabets );
+		reporterr(       "nalphabets = %d\n", nalphabets );
 
 		n_dis = AllocateIntMtx( nalphabets, nalphabets );
 		n_disLN = AllocateDoubleMtx( nalphabets, nalphabets );
@@ -545,6 +555,7 @@ void constants( int nseq, char **seq )
 		freq = AllocateDoubleVec( nalphabets );
 
 		if( ppenalty == NOTSPECIFIED ) ppenalty = DEFAULTGOP_B;
+		if( ppenalty_dist == NOTSPECIFIED ) ppenalty_dist = ppenalty;
 		if( ppenalty_OP == NOTSPECIFIED ) ppenalty_OP = DEFAULTGOP_B;
 		if( ppenalty_ex == NOTSPECIFIED ) ppenalty_ex = DEFAULTGEP_B;
 		if( ppenalty_EX == NOTSPECIFIED ) ppenalty_EX = DEFAULTGEP_B;
@@ -552,6 +563,8 @@ void constants( int nseq, char **seq )
 		if( pamN == NOTSPECIFIED ) pamN = 0;
 		if( kimuraR == NOTSPECIFIED ) kimuraR = 1;
 		penalty = (int)( 600.0 / 1000.0 * ppenalty + 0.5 );
+		penalty_dist = (int)( 600.0 / 1000.0 * ppenalty_dist + 0.5 );
+		penalty_shift = (int)( penalty_shift_factor * penalty );
 		penalty_OP = (int)( 600.0 / 1000.0 * ppenalty_OP + 0.5 );
 		penalty_ex = (int)( 600.0 / 1000.0 * ppenalty_ex + 0.5 );
 		penalty_EX = (int)( 600.0 / 1000.0 * ppenalty_EX + 0.5 );
@@ -562,7 +575,11 @@ void constants( int nseq, char **seq )
 		penalty_exLN = (int)( 600.0 / 1000.0 * -100 + 0.5);
 
 		extendedmtx( n_distmp, freq, amino, amino_grp );
-		sprintf( modelname, "Extended, %6.3f, %+6.3f, %+6.3f", -(double)ppenalty/1000, -(double)poffset/1000, -(double)ppenalty_ex/1000 );
+
+		if( trywarp ) sprintf( shiftmodel, "%4.2f", -(double)penalty_shift/600 );
+		else sprintf( shiftmodel, "noshift" );
+
+		sprintf( modelname, "Extended, %4.2f, %+4.2f, %+4.2f, %s", -(double)ppenalty/1000, -(double)poffset/1000, -(double)ppenalty_ex/1000, shiftmodel );
 #if 0
 		for( i=0; i<26; i++ ) amino[i] = locaminod[i];
 		for( i=0; i<26; i++ ) amino_grp[(int)amino[i]] = locgrpd[i];
@@ -573,7 +590,7 @@ void constants( int nseq, char **seq )
 		for( i=0; i<nalphabets; i++) 
 		{
 			amino_n[(int)amino[i]] = i;
-//			fprintf( stderr, "i=%d, amino = %c, amino_n = %d\n", i, amino[i], amino_n[amino[i]] );
+//			reporterr(       "i=%d, amino = %c, amino_n = %d\n", i, amino[i], amino_n[amino[i]] );
 		}
 		if( fmodel == 1 )
 		{
@@ -583,7 +600,7 @@ void constants( int nseq, char **seq )
 		else
 			freq1 = freq;
 #if TEST
-		fprintf( stderr, "raw scoreing matrix : \n" );
+		reporterr(       "raw scoreing matrix : \n" );
 		for( i=0; i<nalphabets; i++ )
 		{
 			for( j=0; j<nalphabets; j++ ) 
@@ -690,7 +707,7 @@ void constants( int nseq, char **seq )
         	for( i=0; i<nalphabets; i++ )
 				average += n_distmp[i][i] * freq1[i];
 			fprintf( stdout, "itch average = %f\n", average );
-			fprintf( stderr, "parameters: %d, %d, %d\n", penalty, penalty_ex, offset );
+			reporterr(       "parameters: %d, %d, %d\n", penalty, penalty_ex, offset );
 
 			
   			exit( 1 );
@@ -704,7 +721,7 @@ void constants( int nseq, char **seq )
 		FreeDoubleVec( datafreq );
 		FreeDoubleVec( freq );
 
-		fprintf( stderr, "done.\n" );
+		reporterr(       "done.\n" );
 
 	}
 	else if( dorp == 'p' && scoremtx == 1 )  /* Blosum, user-defined */
@@ -726,6 +743,7 @@ void constants( int nseq, char **seq )
 		freq = AllocateDoubleVec( 20 );
 
 		if( ppenalty == NOTSPECIFIED ) ppenalty = DEFAULTGOP_B;
+		if( ppenalty_dist == NOTSPECIFIED ) ppenalty_dist = ppenalty;
 		if( ppenalty_OP == NOTSPECIFIED ) ppenalty_OP = DEFAULTGOP_B;
 		if( ppenalty_ex == NOTSPECIFIED ) ppenalty_ex = DEFAULTGEP_B;
 		if( ppenalty_EX == NOTSPECIFIED ) ppenalty_EX = DEFAULTGEP_B;
@@ -733,6 +751,8 @@ void constants( int nseq, char **seq )
 		if( pamN == NOTSPECIFIED ) pamN = 0;
 		if( kimuraR == NOTSPECIFIED ) kimuraR = 1;
 		penalty = (int)( 600.0 / 1000.0 * ppenalty + 0.5 );
+		penalty_dist = (int)( 600.0 / 1000.0 * ppenalty_dist + 0.5 );
+		penalty_shift = (int)( penalty_shift_factor * penalty );
 		penalty_OP = (int)( 600.0 / 1000.0 * ppenalty_OP + 0.5 );
 		penalty_ex = (int)( 600.0 / 1000.0 * ppenalty_ex + 0.5 );
 		penalty_EX = (int)( 600.0 / 1000.0 * ppenalty_EX + 0.5 );
@@ -743,10 +763,14 @@ void constants( int nseq, char **seq )
 		penalty_exLN = (int)( 600.0 / 1000.0 * -100 + 0.5);
 
 		BLOSUMmtx( nblosum, n_distmp, freq, amino, amino_grp );
+
+		if( trywarp ) sprintf( shiftmodel, "%4.2f", -(double)penalty_shift/600 );
+		else sprintf( shiftmodel, "noshift" );
+
 		if( nblosum == -1 )
-			sprintf( modelname, "User-defined, %6.3f, %+6.3f, %+6.3f", -(double)ppenalty/1000, -(double)poffset/1000, -(double)ppenalty_ex/1000 );
+			sprintf( modelname, "User-defined, %4.2f, %+4.2f, %+4.2f, %s", -(double)ppenalty/1000, -(double)poffset/1000, -(double)ppenalty_ex/1000, shiftmodel );
 		else
-			sprintf( modelname, "BLOSUM%d, %6.3f, %+6.3f, %+6.3f", nblosum, -(double)ppenalty/1000, -(double)poffset/1000, -(double)ppenalty_ex/1000 );
+			sprintf( modelname, "BLOSUM%d, %4.2f, %+4.2f, %+4.2f, %s", nblosum, -(double)ppenalty/1000, -(double)poffset/1000, -(double)ppenalty_ex/1000, shiftmodel );
 #if 0
 		for( i=0; i<26; i++ ) amino[i] = locaminod[i];
 		for( i=0; i<26; i++ ) amino_grp[(int)amino[i]] = locgrpd[i];
@@ -763,7 +787,7 @@ void constants( int nseq, char **seq )
 		else
 			freq1 = freq;
 #if TEST
-		fprintf( stderr, "raw scoreing matrix : \n" );
+		reporterr(       "raw scoreing matrix : \n" );
 		for( i=0; i<20; i++ )
 		{
 			for( j=0; j<20; j++ ) 
@@ -870,7 +894,7 @@ void constants( int nseq, char **seq )
         	for( i=0; i<20; i++ )
 				average += n_distmp[i][i] * freq1[i];
 			fprintf( stdout, "itch average = %f\n", average );
-			fprintf( stderr, "parameters: %d, %d, %d\n", penalty, penalty_ex, offset );
+			reporterr(       "parameters: %d, %d, %d\n", penalty, penalty_ex, offset );
 
 			
   			exit( 1 );
@@ -883,38 +907,13 @@ void constants( int nseq, char **seq )
 		FreeDoubleVec( datafreq );
 		FreeDoubleVec( freq );
 
-		fprintf( stderr, "done.\n" );
+		reporterr(       "done.\n" );
 
 	}
 	else if( dorp == 'p' && scoremtx == 2 ) /* Miyata-Yasunaga */
 	{
-		fprintf( stderr, "Not supported\n" );
+		reporterr(       "Not supported\n" );
 		exit( 1 );
-		for( i=0; i<26; i++ ) for( j=0; j<26; j++ ) n_dis[i][j] = locn_dism[i][j];
-		for( i=0; i<26; i++ ) if( i != 24 ) n_dis[i][24] = n_dis[24][i] = exgpm;
-		n_dis[24][24] = 0;
-		if( ppenalty == NOTSPECIFIED ) ppenalty = locpenaltym;
-		if( poffset == NOTSPECIFIED ) poffset = -20;
-		if( pamN == NOTSPECIFIED ) pamN = 0;
-		if( kimuraR == NOTSPECIFIED ) kimuraR = 1;
-
-		penalty = ppenalty;
-		offset = poffset;
-
-		sprintf( modelname, "Miyata-Yasunaga, %6.3f, %6.3f", -(double)ppenalty/1000, -(double)poffset/1000 );
-		for( i=0; i<26; i++ ) amino[i] = locaminom[i];
-		for( i=0; i<26; i++ ) amino_grp[(int)amino[i]] = locgrpm[i];
-#if DEBUG
-		fprintf( stdout, "scoreing matrix : \n" );
-		for( i=0; i<26; i++ )
-		{
-			for( j=0; j<26; j++ ) 
-			{
-				fprintf( stdout, "%#5d", n_dis[i][j] );
-			}
-			fprintf( stdout, "\n" );
-		}
-#endif
 	}
 	else         /* JTT */
 	{
@@ -942,6 +941,7 @@ void constants( int nseq, char **seq )
 		datafreq = AllocateDoubleVec( 20 );
 
 		if( ppenalty == NOTSPECIFIED ) ppenalty = DEFAULTGOP_J;
+		if( ppenalty_dist == NOTSPECIFIED ) ppenalty_dist = ppenalty;
 		if( ppenalty_OP == NOTSPECIFIED ) ppenalty_OP = DEFAULTGOP_J;
 		if( ppenalty_ex == NOTSPECIFIED ) ppenalty_ex = DEFAULTGEP_J;
 		if( ppenalty_EX == NOTSPECIFIED ) ppenalty_EX = DEFAULTGEP_J;
@@ -950,6 +950,8 @@ void constants( int nseq, char **seq )
 		if( kimuraR == NOTSPECIFIED ) kimuraR = 1;
 
 		penalty = (int)( 600.0 / 1000.0 * ppenalty + 0.5 );
+		penalty_dist = (int)( 600.0 / 1000.0 * ppenalty_dist + 0.5 );
+		penalty_shift = (int)( penalty_shift_factor * penalty );
 		penalty_OP = (int)( 600.0 / 1000.0 * ppenalty_OP + 0.5 );
 		penalty_ex = (int)( 600.0 / 1000.0 * ppenalty_ex + 0.5 );
 		penalty_EX = (int)( 600.0 / 1000.0 * ppenalty_EX + 0.5 );
@@ -959,7 +961,10 @@ void constants( int nseq, char **seq )
 		penaltyLN = (int)( 600.0 / 1000.0 * -2000 + 0.5);
 		penalty_exLN = (int)( 600.0 / 1000.0 * -100 + 0.5);
 
-		sprintf( modelname, "%s %dPAM, %6.3f, %6.3f", (TMorJTT==TM)?"Transmembrane":"JTT", pamN, -(double)ppenalty/1000, -(double)poffset/1000 );
+		if( trywarp ) sprintf( shiftmodel, "%4.2f", -(double)penalty_shift/600 );
+		else sprintf( shiftmodel, "noshift" );
+
+		sprintf( modelname, "%s %dPAM, %4.2f, %4.2f, %s", (TMorJTT==TM)?"Transmembrane":"JTT", pamN, -(double)ppenalty/1000, -(double)poffset/1000, shiftmodel );
 
 		JTTmtx( rsr, freq, amino, amino_grp, (int)(TMorJTT==TM) );
 
@@ -987,7 +992,7 @@ void constants( int nseq, char **seq )
 #endif
 
 
-		fprintf( stderr, "generating %dPAM %s scoring matrix for amino acids ... ", pamN, (TMorJTT==TM)?"Transmembrane":"JTT" );
+		reporterr(       "generating %dPAM %s scoring matrix for amino acids ... ", pamN, (TMorJTT==TM)?"Transmembrane":"JTT" );
 
 		tmp = 0.0;
 		for( i=0; i<20; i++ )
@@ -1039,7 +1044,7 @@ void constants( int nseq, char **seq )
 		{
 			if( pamx[i][j] == 0.0 ) 
 			{
-				fprintf( stderr, "WARNING: pamx[%d][%d] = 0.0?\n", i, j );
+				reporterr(       "WARNING: pamx[%d][%d] = 0.0?\n", i, j );
 				pamx[i][j] = 0.00001; /* by J. Thompson */
 			}
             pamx[i][j] = log10( pamx[i][j] ) * 1000.0;
@@ -1192,7 +1197,7 @@ void constants( int nseq, char **seq )
         	for( i=0; i<20; i++ )
 				average += pamx[i][i] * freq1[i];
 			fprintf( stdout, "itch average = %f\n", average );
-			fprintf( stderr, "parameters: %d, %d, %d\n", penalty, penalty_ex, offset );
+			reporterr(       "parameters: %d, %d, %d\n", penalty, penalty_ex, offset );
 
 			
   			exit( 1 );
@@ -1201,7 +1206,7 @@ void constants( int nseq, char **seq )
 		for( i=0; i<26; i++ ) for( j=0; j<26; j++ ) n_dis[i][j] = 0;
 		for( i=0; i<20; i++ ) for( j=0; j<20; j++ ) n_dis[i][j] = (int)pamx[i][j];
 
-		fprintf( stderr, "done.\n" );
+		reporterr(       "done.\n" );
 		FreeDoubleMtx( rsr );
 		FreeDoubleMtx( pam1 );
 		FreeDoubleMtx( pamx );
@@ -1209,11 +1214,11 @@ void constants( int nseq, char **seq )
 		FreeDoubleVec( mutab );
 		FreeDoubleVec( datafreq );
 	}
-	fprintf( stderr, "scoremtx = %d\n", scoremtx );
+	reporterr(       "scoremtx = %d\n", scoremtx );
 
 #if DEBUG
-	fprintf( stderr, "scoremtx = %d\n", scoremtx );
-	fprintf( stderr, "amino[] = %s\n", amino );
+	reporterr(       "scoremtx = %d\n", scoremtx );
+	reporterr(       "amino[] = %s\n", amino );
 #endif
 
 	for( i=0; i<0x80; i++ )amino_n[i] = -1;
@@ -1258,44 +1263,44 @@ void constants( int nseq, char **seq )
 	}
 
 #if 0
-		fprintf( stderr, "amino_dis (offset = %d): \n", offset );
+		reporterr(       "amino_dis (offset = %d): \n", offset );
 		for( i=0; i<20; i++ )
 		{
 			for( j=0; j<20; j++ ) 
 			{
-				fprintf( stderr, "%5d", amino_dis[(int)amino[i]][(int)amino[j]] );
+				reporterr(       "%5d", amino_dis[(int)amino[i]][(int)amino[j]] );
 			}
-			fprintf( stderr, "\n" );
+			reporterr(       "\n" );
 		}
 
-		fprintf( stderr, "amino_disLN (offsetLN = %d): \n", offsetLN );
+		reporterr(       "amino_disLN (offsetLN = %d): \n", offsetLN );
 		for( i=0; i<20; i++ )
 		{
 			for( j=0; j<20; j++ ) 
 			{
-				fprintf( stderr, "%5d", amino_disLN[(int)amino[i]][(int)amino[j]] );
+				reporterr(       "%5d", amino_disLN[(int)amino[i]][(int)amino[j]] );
 			}
-			fprintf( stderr, "\n" );
+			reporterr(       "\n" );
 		}
 
-		fprintf( stderr, "n_dis (offset = %d): \n", offset );
+		reporterr(       "n_dis (offset = %d): \n", offset );
 		for( i=0; i<26; i++ )
 		{
 			for( j=0; j<26; j++ ) 
 			{
-				fprintf( stderr, "%5d", n_dis[i][j] );
+				reporterr(       "%5d", n_dis[i][j] );
 			}
-			fprintf( stderr, "\n" );
+			reporterr(       "\n" );
 		}
 
-		fprintf( stderr, "n_disFFT (offsetFFT = %d): \n", offsetFFT );
+		reporterr(       "n_disFFT (offsetFFT = %d): \n", offsetFFT );
 		for( i=0; i<26; i++ )
 		{
 			for( j=0; j<26; j++ ) 
 			{
-				fprintf( stderr, "%5d", n_disFFT[i][j] );
+				reporterr(       "%5d", n_disFFT[i][j] );
 			}
-			fprintf( stderr, "\n" );
+			reporterr(       "\n" );
 		}
 exit( 1 );
 #endif
@@ -1343,3 +1348,11 @@ exit( 1 );
 #endif
 	}
 }
+
+void freeconstants()
+{
+	FreeDoubleMtx( n_disLN );
+	FreeIntMtx( n_dis );
+	FreeIntMtx( n_disFFT );
+	FreeDoubleMtx( n_dis_consweight_multi );
+}
