@@ -11,7 +11,7 @@ int randomseed = 0;
 int parallelizationstrategy = BAATARI1;
 
 
-char modelname[100];
+char modelname[500];
 int njob, nlenmax;
 int amino_n[0x80];
 char amino_grp[0x80];
@@ -49,12 +49,16 @@ int refine;
 int check;
 double cut;
 int cooling;
+int trywarp = 0;
 int penalty, ppenalty, penaltyLN;
+int penalty_dist, ppenalty_dist;
 int RNApenalty, RNAppenalty;
 int RNApenalty_ex, RNAppenalty_ex;
 int penalty_ex, ppenalty_ex, penalty_exLN;
 int penalty_EX, ppenalty_EX;
 int penalty_OP, ppenalty_OP;
+int penalty_shift, ppenalty_shift;
+double penalty_shift_factor = 100.0;
 int RNAthr, RNApthr;
 int offset, poffset, offsetLN, offsetFFT;
 int scoremtx;
@@ -114,3 +118,38 @@ int nscoredalphabets = 20;
 double specificityconsideration = 0.0;
 int ndistclass = 10;
 int maxdistclass = -1;
+
+int gmsg = 0;
+
+void initglobalvariables()
+{
+	commonAlloc1 = 0;
+	commonAlloc2 = 0;
+	commonIP = NULL;
+	commonJP = NULL;
+	nthread = 1;
+	randomseed = 0;
+	parallelizationstrategy = BAATARI1;
+
+	trywarp = 0;
+	penalty_shift_factor = 100.0;
+	outgap = 1;
+	addprofile = 1;
+	scoreout = 0;
+	outnumber = 0;
+	legacygapcost = 0;
+	consweight_multi = 1.0;
+	consweight_rna = 0.0;
+	RNAscoremtx = 'n';
+
+	newgapstr = "-";
+
+	nalphabets = 26;
+	nscoredalphabets = 20;
+
+	specificityconsideration = 0.0;
+	ndistclass = 10;
+	maxdistclass = -1;
+	
+	gmsg = 0;
+}
