@@ -11,6 +11,24 @@ static int subalignmentoffset;
 static int intop;
 static int intree;
 
+
+static void calcmaxdistclass( void )
+{
+	int c;
+	float rep;
+	for( c=0; c<ndistclass; c++ )
+	{
+		rep = (double) 2 * c / ndistclass; // dist:0-2 for dist2offset 
+//		fprintf( stderr, "c=%d, rep=%f, offset=%f\n", c, rep, dist2offset( rep )  );
+		if( dist2offset( rep ) == 0.0 )
+			break;
+	}
+	fprintf( stderr, "ndistclass = %d, maxdistclass = %d\n", ndistclass, c+1 );
+	maxdistclass = c + 1;
+//	maxdistclass = ndistclass; // CHUUI!!!!
+	return;
+}
+
 void arguments( int argc, char *argv[] )
 {
 	int c;
@@ -61,6 +79,7 @@ void arguments( int argc, char *argv[] )
 	scoremtx = 1;
 	dorp = NOTSPECIFIED;
 	ppenalty = NOTSPECIFIED;
+	penalty_shift_factor = 1000.0;
 	ppenalty_ex = NOTSPECIFIED;
 	poffset = NOTSPECIFIED;
 	kimuraR = NOTSPECIFIED;
@@ -77,6 +96,7 @@ void arguments( int argc, char *argv[] )
 	subalignment = 0;
 	subalignmentoffset = 0;
 	legacygapcost = 0;
+	specificityconsideration = 0.0;
 
 	while( --argc > 0 && (*++argv)[0] == '-' )
 	{
@@ -107,6 +127,15 @@ void arguments( int argc, char *argv[] )
 //					fprintf( stderr, "ppenalty = %d\n", ppenalty );
 					--argc;
 					goto nextoption;
+				case 'Q':
+					penalty_shift_factor = atof( *++argv );
+					if( penalty_shift_factor < 100.0 && penalty_shift_factor != 2.0 )
+					{
+						fprintf( stderr, "%f, penalty_shift is fixed to penalty x 2 in the iterative refinement phase.\n", penalty_shift_factor );
+						penalty_shift_factor = 2.0;
+					}
+					--argc;
+					goto nextoption;
 				case 'g':
 					ppenalty_ex = (int)( atof( *++argv ) * 1000 - 0.5 );
 //					fprintf( stderr, "ppenalty_ex = %d\n", ppenalty_ex );
@@ -185,12 +214,19 @@ void arguments( int argc, char *argv[] )
 //					exit( 1 );
 					--argc; 
 					goto nextoption;
+				case 's':
+					specificityconsideration = (double)myatof( *++argv );
+//					fprintf( stderr, "specificityconsideration = %f\n", specificityconsideration );
+					--argc; 
+					goto nextoption;
 				case 'S' :
 					scoreout = 1;
 					break;
+#if 0
 				case 's' :
 					RNAscoremtx = 'r';
 					break;
+#endif
 #if 1
 				case 'a':
 					fmodel = 1;
@@ -205,9 +241,11 @@ void arguments( int argc, char *argv[] )
 				case 'P':
 					dorp = 'p';
 					break;
+#if 0
 				case 'Q':
 					alg = 'Q';
 					break;
+#endif
 				case 'R':
 					rnaprediction = 'r';
 					break;
@@ -373,6 +411,7 @@ int main( int argc, char *argv[] )
 #ifndef enablemultithread
 	nthread = 0;
 #endif
+	if( fastathreshold < 0.0001 ) constraint = 0;
 
 	if( inputfile )
 	{
@@ -517,6 +556,7 @@ int main( int argc, char *argv[] )
 #endif
 	fclose( infp );
 
+	if( specificityconsideration ) calcmaxdistclass();
 
 	for( i=0; i<njob; i++ )
 	{
@@ -604,18 +644,33 @@ int main( int argc, char *argv[] )
 		if( !prep ) ErrorExit( "Make hat2." );
 		readhat2_pointer( prep, njob, name, eff );
 		fclose( prep );
-#if DEBUG
+#if 0
+		fprintf( stderr, "eff = \n" );
 		for( i=0; i<njob-1; i++ ) 
 		{
 			for( j=i+1; j<njob; j++ ) 
 			{
-				printf( " %f", eff[i][j] );
+				fprintf( stderr, "%d-%d,  %f\n", i, j, eff[i][j] );
 			}
-			printf( "\n" );
+			fprintf( stderr, "\n" );
 		}
 #endif
 		if( intree )
+		{
 			veryfastsupg_double_loadtree( njob, eff, topol, len, name );
+#if 0
+			fprintf( stderr, "eff = \n" );
+			for( i=0; i<njob-1; i++ ) 
+			{
+				for( j=i+1; j<njob; j++ ) 
+				{
+					fprintf( stderr, "%d-%d,  %f\n", i, j, eff[i][j] );
+				}
+				fprintf( stderr, "\n" );
+			}
+exit( 1 );
+#endif
+		}
 		else if( intop ) // v6.528 deha if( intop ) dattanode intree ga mukou datta.
 		{
 			fprintf( stderr, "--topin has been disabled\n" );
@@ -829,7 +884,7 @@ int main( int argc, char *argv[] )
 		fprintf( trap_g, "Segment %3d/%3d %4d-%4d\n", iseg+1, nseg-1, pos+1, pos+1+tmplen );
 	
 		cut = ocut;
-		returnvalue = TreeDependentIteration( njob, name, nlen, seq, bseq, topol, len, skipthisbranch, alloclen, localhomtable, singlerna, nkozo, kozoarivec );
+		returnvalue = TreeDependentIteration( njob, name, nlen, seq, bseq, topol, len, eff, skipthisbranch, alloclen, localhomtable, singlerna, nkozo, kozoarivec );
 
 		for( i=0; i<njob; i++ )
 			strcat( res_g[i], bseq[i] );
