@@ -52,8 +52,9 @@ int fft(int n, Fukusosuu *x, int freeflag)
 
 		if (freeflag)
 		{
-			if (bitrev) free(bitrev);
-			if (sintbl) free(sintbl);
+			if (bitrev) free(bitrev); bitrev = NULL;
+			if (sintbl) free(sintbl); sintbl = NULL;
+			last_n = 0;
 			return( 0 );
 		}
 
