@@ -211,6 +211,7 @@ int alignableReagion( int    clus1, int    clus2,
 		if( prf2 ) FreeDoubleVec( prf2 ); prf2 = NULL;
 		if( hat1 ) FreeIntVec( hat1 ); hat1 = NULL;
 		if( hat2 ) FreeIntVec( hat2 ); hat2 = NULL;
+		alloclen = 0;
 		return( 0 );
 	}
 
@@ -405,8 +406,9 @@ void blockAlign2( int *cut1, int *cut2, Segment **seg1, Segment **seg2, double *
 			if( ocut1 ) free( ocut1 ); ocut1 = NULL;
 			if( ocut2 ) free( ocut2 ); ocut2 = NULL;
 			if( track ) FreeIntMtx( track ); track = NULL;
-        	if( crossscore ) FreeDoubleMtx( crossscore ); crossscore = NULL;
+	        	if( crossscore ) FreeDoubleMtx( crossscore ); crossscore = NULL;
 		}
+		crossscoresize = 0;
 		return;
 	}
 
