@@ -87,9 +87,6 @@ char **arguments( int argc, char *argv[] )
 				case 'Q':
 					alg = 'Q';
 					break;
-				case 'H':
-					alg = 'H';
-					break;
 				case 'A':
 					alg = 'A';
 					break;
@@ -237,11 +234,6 @@ void GroupAlign( int nseq1, int nseq2, char **name, int *nlen, char **seq, char
 	fprintf( stderr, "\n" );
 */
 
-	if( alg == 'Q' )
-		fprintf( stderr, "before realignment, score = %f\n", naiveQpairscore( nseq1, nseq2, mseq1, mseq2, effarr1, effarr2, penalty ) );
-	else if( alg == 'H' )
-		fprintf( stderr, "before realignment, score = %f\n", naivepairscore( nseq1, nseq2, mseq1, mseq2, effarr1, effarr2, penalty ) );
-
 	commongappick( nseq1, mseq1 );
 	commongappick( nseq2, mseq2 );
 
@@ -261,10 +253,6 @@ void GroupAlign( int nseq1, int nseq2, char **name, int *nlen, char **seq, char
 	{
 		if( alg == 'M' )
 			pscore = MSalignmm( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
-		else if( alg == 'H' )
-			pscore = H__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-		else if( alg == 'Q' )
-			pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
 		else
 			pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 	}
@@ -274,11 +262,6 @@ void GroupAlign( int nseq1, int nseq2, char **name, int *nlen, char **seq, char
 		fflush( stdout );
 #endif
 
-	if( alg == 'H' )
-		fprintf( stderr, "before realignment, score = %f\n", naivepairscore( nseq1, nseq2, mseq1, mseq2, effarr1, effarr2, penalty ) );
-	else if( alg == 'Q' )
-		fprintf( stderr, "after realignment, score = %f\n", naiveQpairscore( nseq1, nseq2, mseq1, mseq2, effarr1, effarr2, penalty ) );
-
 	
 /*
 	fprintf( stderr, "after align 1 %s \n", indication1 );
