@@ -6,6 +6,7 @@
 #else
 #endif
 
+#include "mafft.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <stddef.h>
@@ -16,12 +17,13 @@
 #include <ctype.h>
 #include "mtxutl.h"
 #include <float.h>
+#include <stdarg.h>
 #ifdef enablemultithread
 #include <pthread.h>
 #endif
 
-#define VERSION "7.127b"
-#define SHOWVERSION fprintf( stderr, "%s (%s) Version " VERSION " alg=%c, model=%s\n%d thread(s)\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, nthread )
+#define VERSION "7.164b"
+#define SHOWVERSION reporterr( "%s (%s) Version " VERSION " alg=%c, model=%s, amax=%3.1f\n%d thread(s)\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, specificityconsideration, nthread )
 
 #define FFT_THRESHOLD  80
 #define FFT_WINSIZE_P   20
@@ -51,7 +53,7 @@
 #define JTT 201
 #define TM  202
 
-extern char modelname[100];
+extern char modelname[500];
 extern int njob, nlenmax;
 extern int amino_n[0x80];
 extern char amino_grp[0x80];
@@ -89,12 +91,16 @@ extern int refine;
 extern int check;
 extern double cut;
 extern int cooling;
+extern int trywarp;
 extern int penalty, ppenalty, penaltyLN;
+extern int penalty_dist, ppenalty_dist;
 extern int RNApenalty, RNAppenalty;
 extern int RNApenalty_ex, RNAppenalty_ex;
 extern int penalty_ex, ppenalty_ex, penalty_exLN;
 extern int penalty_EX, ppenalty_EX;
 extern int penalty_OP, ppenalty_OP;
+extern int penalty_shift;
+extern double penalty_shift_factor;
 extern int offset, poffset, offsetLN, offsetFFT;
 extern int RNAthr, RNApthr;
 extern int scoremtx;
@@ -160,7 +166,7 @@ extern float A__align();
 extern float A__align11();
 extern float A__align_gapmap();
 extern float partA__align();
-extern float L__align11();
+extern float L__align11( double **scoringmtx, float scoreoffset, char **seq1, char **seq2, int alloclen, int *off1pt, int *off2pt );
 extern float G__align11();
 extern float Falign();
 extern float Falign_localhom();
@@ -282,7 +288,6 @@ typedef struct _Addtree
 	float dist2;
 } Addtree;
 
-
 #include "fft.h"
 #include "dp.h"
 #include "functions.h"
@@ -316,3 +321,5 @@ extern int nalphabets;
 extern int nscoredalphabets;
 extern double specificityconsideration;
 extern int ndistclass, maxdistclass;
+
+extern int gmsg;
