@@ -575,6 +575,7 @@ void arguments( int argc, char *argv[] )
 	dorp = NOTSPECIFIED;
 	ppenalty = -1530;
 	ppenalty_ex = NOTSPECIFIED;
+	penalty_shift_factor = 1000.0;
 	poffset = -123;
 	kimuraR = NOTSPECIFIED;
 	pamN = NOTSPECIFIED;
@@ -613,6 +614,10 @@ void arguments( int argc, char *argv[] )
 //					fprintf( stderr, "ppenalty = %d\n", ppenalty );
 					--argc;
 					goto nextoption;
+				case 'Q':
+					penalty_shift_factor = atof( *++argv );
+					--argc;
+					goto nextoption;
 				case 'g':
 					ppenalty_ex = (int)( atof( *++argv ) * 1000 - 0.5 );
 					fprintf( stderr, "ppenalty_ex = %d\n", ppenalty_ex );
@@ -703,13 +708,13 @@ void arguments( int argc, char *argv[] )
 				case 'a':
 					alg = 'a';
 					break;
-#endif
 				case 'R':
 					alg = 'R';
 					break;
 				case 'Q':
 					alg = 'Q';
 					break;
+#endif
 				case 'A':
 					alg = 'A';
 					break;
@@ -1006,12 +1011,12 @@ static void pairalign( int nseq, int *nlen, char **seq, int *mem1, int *mem2, do
 		{
 			fprintf( stderr, "\bm" );
 //			fprintf( stderr, "%d-%d", clus1, clus2 );
-			pscore = Falign_udpari_long( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1 );
+			pscore = Falign_udpari_long( NULL, NULL, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1 );
 		}
 		else
 		{
 //			fprintf( stderr, "%d-%d", clus1, clus2 );
-			pscore = Falign( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
+			pscore = Falign( NULL, NULL, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, *alloclen, fftlog+m1, NULL, 0, NULL );
 		}
 	}
 	else
@@ -1026,30 +1031,18 @@ static void pairalign( int nseq, int *nlen, char **seq, int *mem1, int *mem2, do
 			case( 'M' ):
 				fprintf( stderr, "\bm" );
 //				fprintf( stderr, "%d-%d", clus1, clus2 );
-				pscore = MSalignmm( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
-				break;
-			case( 'Q' ):
-				if( clus1 == 1 && clus2 == 1 )
-				{
-//					fprintf( stderr, "%d-%d", clus1, clus2 );
-					pscore = G__align11( mseq1, mseq2, *alloclen, outgap, outgap );
-				}
-				else
-				{
-//					fprintf( stderr, "%d-%d", clus1, clus2 );
-					pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-				}
+				pscore = MSalignmm( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 				break;
 			case( 'A' ):
 				if( clus1 == 1 && clus2 == 1 )
 				{
 //					fprintf( stderr, "%d-%d", clus1, clus2 );
-					pscore = G__align11( mseq1, mseq2, *alloclen, outgap, outgap );
+					pscore = G__align11( n_dis_consweight_multi, mseq1, mseq2, *alloclen, outgap, outgap );
 				}
 				else
 				{
 //					fprintf( stderr, "%d-%d", clus1, clus2 );
-					pscore = A__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 				}
 				break;
 			default:
@@ -1405,7 +1398,7 @@ static int splitseq_mq( Scores *scores, int nin, int *nlen, char **seq, char **o
 				{
 					if( fromaln )
 					{
-//						scores[i].score = ( 1.0 - (double)G__align11_noalign( amino_disLN, mseq1, mseq2, palloclen ) / MIN( selfscore0, scores[i].selfscore ) ) * 1;
+//						scores[i].score = ( 1.0 - (double)G__align11_noalign( n_disLN, mseq1, mseq2, palloclen ) / MIN( selfscore0, scores[i].selfscore ) ) * 1;
 						scores[i].score = ( 1.0 - (double)naivepairscore11( orialn[scores[i].numinseq], orialn[scores->numinseq], penalty ) / MIN( selfscore0, scores[i].selfscore ) ) * 1;
 					}
 					else
@@ -1413,7 +1406,7 @@ static int splitseq_mq( Scores *scores, int nin, int *nlen, char **seq, char **o
 						if( *depthpt == 0 ) fprintf( stderr, "\r%d / %d   ", i, nin );
 						gappick0( mseq2[0], seq[scores[i].numinseq] );
 //						fprintf( stdout, "### before calc scores[%d] = %f (%c)\n", i, scores[i].score, qinoya == scores->numinseq?'o':'x' );
-						scores[i].score = ( 1.0 - (double)G__align11_noalign( amino_disLN, -1200, -60, mseq1, mseq2, palloclen ) / MIN( selfscore0, scores[i].selfscore ) ) * 1;
+						scores[i].score = ( 1.0 - (double)G__align11_noalign( n_disLN, -1200, -60, mseq1, mseq2, palloclen ) / MIN( selfscore0, scores[i].selfscore ) ) * 1;
 //						fprintf( stderr, "scores[i] = %f\n", scores[i].score );
 //						fprintf( stderr, "m1=%s\n", seq[scores[0].numinseq] );
 //						fprintf( stderr, "m2=%s\n", seq[scores[i].numinseq] );
@@ -1677,7 +1670,7 @@ exit( 1 );
 					{
 //						fprintf( stderr, "\r%d / %d   ", i, nin );
 						gappick0( mseq2[0], seq[scores[picks[i]].numinseq] );
-						pickmtx[j][i-j] = ( 1.0 - (double)G__align11_noalign( amino_disLN, -1200, -60, mseq1, mseq2, palloclen ) / MIN( selfscore0, scores[picks[i]].selfscore ) ) * 1;
+						pickmtx[j][i-j] = ( 1.0 - (double)G__align11_noalign( n_disLN, -1200, -60, mseq1, mseq2, palloclen ) / MIN( selfscore0, scores[picks[i]].selfscore ) ) * 1;
 	//					fprintf( stderr, "scores[picks[i]] = %f\n", scores[picks[i]].score );
 					}
 				}
@@ -2196,7 +2189,7 @@ exit( 1 );
 							else
 							{
 								gappick0( mseq2[0], seq[scores[j].numinseq] );
-								dfromc[i][j] = ( 1.0 - (double)G__align11_noalign( amino_disLN, -1200, -60, mseq1, mseq2, palloclen ) / MIN( selfscore0, scores[j].selfscore ) ) * 1;
+								dfromc[i][j] = ( 1.0 - (double)G__align11_noalign( n_disLN, -1200, -60, mseq1, mseq2, palloclen ) / MIN( selfscore0, scores[j].selfscore ) ) * 1;
 							}
 						}
 					}
@@ -2845,7 +2838,7 @@ int main( int argc, char *argv[] )
 //		fprintf( stdout, ">%s\n", name[i] );
 //		fprintf( stdout, "%s\n", seq[i] );
 	}
-	if( nunknown ) fprintf( stderr, "\nWARNING : %d unknown characters\n", nunknown );
+	if( nunknown ) fprintf( stderr, "\nThere are %d ambiguous characters\n", nunknown );
 //	exit( 1 );
 
 #if 0
@@ -2981,6 +2974,7 @@ int main( int argc, char *argv[] )
 				pscore = 0;
 				for( pt=seq[i]; *pt; pt++ )
 				{
+//					pscore += amino_dis[(int)*pt][(int)*pt];
 					pscore += amino_dis[(int)*pt][(int)*pt];
 				}
 				scores[i].selfscore = pscore; 
