@@ -100,7 +100,9 @@ void arguments( int argc, char *argv[] )
 	scoremtx = 1;
 	kobetsubunkatsu = 0;
 	dorp = NOTSPECIFIED;
+	ppenalty_dist = NOTSPECIFIED;
 	ppenalty = NOTSPECIFIED;
+	penalty_shift_factor = 1000.0;
 	ppenalty_ex = NOTSPECIFIED;
 	poffset = NOTSPECIFIED;
 	kimuraR = NOTSPECIFIED;
@@ -144,11 +146,20 @@ void arguments( int argc, char *argv[] )
 					RNAppenalty = (int)( atof( *++argv ) * 1000 - 0.5 );
 					--argc;
 					goto nextoption;
+				case 'V':
+					ppenalty_dist = (int)( atof( *++argv ) * 1000 - 0.5 );
+//					fprintf( stderr, "ppenalty = %d\n", ppenalty );
+					--argc;
+					goto nextoption;
 				case 'f':
 					ppenalty = (int)( atof( *++argv ) * 1000 - 0.5 );
 //					fprintf( stderr, "ppenalty = %d\n", ppenalty );
 					--argc;
 					goto nextoption;
+				case 'Q':
+					penalty_shift_factor = atof( *++argv );
+					--argc;
+					goto nextoption;
 				case 'g':
 					ppenalty_ex = (int)( atof( *++argv ) * 1000 - 0.5 );
 					fprintf( stderr, "ppenalty_ex = %d\n", ppenalty_ex );
@@ -203,11 +214,6 @@ void arguments( int argc, char *argv[] )
 					fprintf( stderr, "nthread = %d\n", nthread );
 					--argc; 
 					goto nextoption;
-				case 'H':
-					subalignment = 1;
-					subalignmentoffset = myatoi( *++argv );
-					--argc;
-					goto nextoption;
 				case 's':
 					specificityconsideration = (double)myatof( *++argv );
 //					fprintf( stderr, "specificityconsideration = %f\n", specificityconsideration );
@@ -253,6 +259,11 @@ void arguments( int argc, char *argv[] )
 				case 'S':
 					scoreout = 1;
 					break;
+				case 'H':
+					subalignment = 1;
+					subalignmentoffset = myatoi( *++argv );
+					--argc;
+					goto nextoption;
 #if 0
 				case 'e':
 					fftscore = 0;
@@ -286,10 +297,10 @@ void arguments( int argc, char *argv[] )
 				case 'H':
 					alg = 'H';
 					break;
-#endif
 				case 'Q':
 					alg = 'Q';
 					break;
+#endif
 				case 'A':
 					alg = 'A';
 					break;
@@ -311,9 +322,11 @@ void arguments( int argc, char *argv[] )
 				case 'U':
 					treein = 1;
 					break;
+#if 0
 				case 'V':
 					topin = 1;
 					break;
+#endif
 				case 'u':
 					tbrweight = 0;
 					weight = 0;
@@ -412,7 +425,7 @@ static void *distancematrixthread2( void *arg )
 			if( bunbo == 0.0 )
 				iscore[i][j-i] = 1.0;
 			else
-				iscore[i][j-i] = 1.0 - naivepairscore11( seq[i], seq[j], penalty ) / bunbo;
+				iscore[i][j-i] = 1.0 - naivepairscore11( seq[i], seq[j], penalty_dist ) / bunbo;
 		}
 	}
 }
@@ -460,7 +473,7 @@ static void *distancematrixthread( void *arg )
 		if( bunbo == 0.0 )
 			iscore[i][j-i] = 2.0; // 2013/Oct/17
 		else
-			iscore[i][j-i] = ( 1.0 - naivepairscore11( seq[i], seq[j], penalty ) / bunbo ) * 2.0; // 2013/Oct/17
+			iscore[i][j-i] = ( 1.0 - naivepairscore11( seq[i], seq[j], penalty_dist ) / bunbo ) * 2.0; // 2013/Oct/17
 	}
 }
 
@@ -764,21 +777,10 @@ static void *treebasethread( void *arg )
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
 				pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
-			else if( alg == 'H' )
-			{
-				imp_match_init_strictH( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-				pscore = H__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL );
-			}
 			else if( alg == 'Q' )
 			{
-				imp_match_init_strictQ( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-				if( rnakozo ) imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
-				pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL );
-			}
-			else if( alg == 'R' )
-			{
-				imp_match_init_strictR( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-				pscore = R__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL );
+				fprintf( stderr, "Not supported\n" );
+				exit( 1 );
 			}
 		}
 		else if( force_fft || ( use_fft && ffttry ) )
@@ -808,15 +810,6 @@ static void *treebasethread( void *arg )
 				case( 'A' ):
 					pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
-				case( 'Q' ):
-					pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-					break;
-				case( 'R' ):
-					pscore = R__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-					break;
-				case( 'H' ):
-					pscore = H__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-					break;
 				default:
 					ErrorExit( "ERROR IN SOURCE FILE" );
 			}
@@ -888,7 +881,7 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 	float dumfl = 0.0;
 	int ffttry;
 	RNApair ***grouprna1 = NULL, ***grouprna2 = NULL;
-	double **dynamicmtx;
+	static double **dynamicmtx;
 
 	if( rnakozo && rnaprediction == 'm' )
 	{
@@ -1104,21 +1097,10 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
 				pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
-			else if( alg == 'H' )
-			{
-				imp_match_init_strictH( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-				pscore = H__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL );
-			}
 			else if( alg == 'Q' )
 			{
-				imp_match_init_strictQ( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-				if( rnakozo ) imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
-				pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL );
-			}
-			else if( alg == 'R' )
-			{
-				imp_match_init_strictR( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-				pscore = R__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumfl, NULL, NULL, NULL, NULL );
+				fprintf( stderr, "Not supported\n" );
+				exit( 1 );
 			}
 		}
 		else if( force_fft || ( use_fft && ffttry ) )
@@ -1148,15 +1130,6 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 				case( 'A' ):
 					pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
-				case( 'Q' ):
-					pscore = Q__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-					break;
-				case( 'R' ):
-					pscore = R__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-					break;
-				case( 'H' ):
-					pscore = H__align( mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumfl, NULL, NULL, NULL, NULL );
-					break;
 				default:
 					ErrorExit( "ERROR IN SOURCE FILE" );
 			}
@@ -1510,7 +1483,9 @@ int main( int argc, char *argv[] )
 			ien = njob-1;
 			for( i=0; i<njob; i++ ) 
 			{
-				selfscore[i] = naivepairscore11( seq[i], seq[i], penalty );
+				selfscore[i] = naivepairscore11( seq[i], seq[i], penalty_dist );
+//				fprintf( stderr, "penalty = %d\n", penalty );
+//				fprintf( stderr, "penalty_dist = %d\n", penalty_dist );
 			}
 #ifdef enablemultithread
 			if( nthread > 0 )
@@ -1566,14 +1541,14 @@ int main( int argc, char *argv[] )
 						if( bunbo == 0.0 )
 							iscore[i][j-i] = 2.0; // 2013/Oct/17 2bai
 						else
-//							iscore[i][j-i] = 1.0 - naivepairscore11( seq[i], seq[j], penalty ) / MIN( selfscore[i], selfscore[j] );
-							iscore[i][j-i] = ( 1.0 - naivepairscore11( seq[i], seq[j], penalty ) / bunbo ) * 2.0; // 2013/Oct/17 2bai
+//							iscore[i][j-i] = 1.0 - naivepairscore11( seq[i], seq[j], penalty_dist ) / MIN( selfscore[i], selfscore[j] );
+							iscore[i][j-i] = ( 1.0 - naivepairscore11( seq[i], seq[j], penalty_dist ) / bunbo ) * 2.0; // 2013/Oct/17 2bai
 		
 #if 0
 						fprintf( stderr, "### ssj = %f\n", ssj );
 						fprintf( stderr, "### selfscore[i] = %f\n", selfscore[i] );
 						fprintf( stderr, "### selfscore[j] = %f\n", selfscore[j] );
-						fprintf( stderr, "### rawscore = %f\n", naivepairscore11( seq[i], seq[j], penalty ) );
+						fprintf( stderr, "### rawscore = %f\n", naivepairscore11( seq[i], seq[j], penalty_dist ) );
 #endif
 					}
 				}
