@@ -252,7 +252,7 @@ static void freelocalarrays(
 	if( commonIP ) FreeIntMtx( commonIP );
 	commonIP = NULL;
 	Falign( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
-	Falign_localhom( NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL,NULL, 0, NULL );
+	Falign_localhom( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL,NULL, 0, NULL );
 	if( rnakozo && rnaprediction == 'm' )
 	{
 		free( grouprna1 ); // nakamimo?
@@ -855,13 +855,8 @@ static void *athread( void *arg )
 					{
 						if( alg == 'Q' )
 						{
-							part_imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-							if( rnakozo ) part_imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
-							for(  i=length-1; i>=0; i-- )
-							{
-								oimpmatch += part_imp_match_out_scQ( i, i );
-//								fprintf( stderr, "#### i=%d, initial impmatch = %f seq1 = %c, seq2 = %c\n", i, oimpmatch, mseq1[0][i], mseq2[0][i] );
-							}
+							fprintf( stderr, "'Q' is no longer supported\n" );
+							exit( 1 );
 						}
 						else
 						{
@@ -879,14 +874,8 @@ static void *athread( void *arg )
 					{
 						if( alg == 'Q' )
 						{
-							imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-							if( rnakozo ) imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
-
-							for(  i=length-1; i>=0; i-- )
-							{
-								oimpmatch += imp_match_out_scQ( i, i );
-//								fprintf( stderr, "#### i=%d, initial impmatch = %f\n", i, oimpmatch );
-							}
+							fprintf( stderr, "'Q' is no longer supported\n" );
+							exit( 1 );
 						}
 						else
 						{
@@ -975,7 +964,7 @@ static void *athread( void *arg )
 //						else
 //							part_imp_match_init_strict( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
 						chudanres = 0;
-						Falign_localhom( mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, localhomshrink, &impmatch, gapmap1, gapmap2, subgenerationpt, subgenerationatfirst, &chudanres );
+						Falign_localhom( NULL, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatch, gapmap1, gapmap2, subgenerationpt, subgenerationatfirst, &chudanres );
 //						fprintf( stderr, "##### impmatch = %f\n", impmatch );
 						if( chudanres && parallelizationstrategy == BAATARI2 )
 						{
@@ -1763,9 +1752,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 							{
 								if( alg == 'Q' )
 								{
-									part_imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-									if( rnakozo ) part_imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
-									for(  i=length-1; i>=0; i-- ) oimpmatch += part_imp_match_out_scQ( i, i );
+									fprintf( stderr, "'Q' is no longer supported\n" );
+									exit( 1 );
 								}
 								else
 								{
@@ -1778,9 +1766,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 							{
 								if( alg == 'Q' )
 								{
-									imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-									if( rnakozo ) imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
-									for(  i=length-1; i>=0; i-- ) oimpmatch += imp_match_out_scQ( i, i );
+									fprintf( stderr, "'Q' is no longer supported\n" );
+									exit( 1 );
 								}
 								else
 								{
@@ -1847,13 +1834,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 							{
 								if( alg == 'Q' )
 								{
-									part_imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-									if( rnakozo ) part_imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
-									for(  i=length-1; i>=0; i-- )
-									{
-										oimpmatch += part_imp_match_out_scQ( i, i );
-	//									fprintf( stderr, "#### i=%d, initial impmatch = %f seq1 = %c, seq2 = %c\n", i, oimpmatch, mseq1[0][i], mseq2[0][i] );
-									}
+									fprintf( stderr, "'Q' is no longer supported\n" );
+									exit( 1 );
 								}
 								else
 								{
@@ -1871,14 +1853,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 							{
 								if( alg == 'Q' )
 								{
-									imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-									if( rnakozo ) imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
-	
-									for(  i=length-1; i>=0; i-- )
-									{
-										oimpmatch += imp_match_out_scQ( i, i );
-	//									fprintf( stderr, "#### i=%d, initial impmatch = %f\n", i, oimpmatch );
-									}
+									fprintf( stderr, "'Q' is no longer supported\n" );
+									exit( 1 );
 								}
 								else
 								{
@@ -1936,8 +1912,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 							{
 								if( alg == 'Q' )
 								{
-									part_imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-									if( rnakozo ) part_imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
+									fprintf( stderr, "'Q' is no longer supported\n" );
+									exit( 1 );
 								}
 								else
 								{
@@ -1949,8 +1925,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 							{
 								if( alg == 'Q' )
 								{
-									imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
-									if( rnakozo ) imp_rnaQ( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
+									fprintf( stderr, "'Q' is no longer supported\n" );
+									exit( 1 );
 								}
 								else
 								{
@@ -2031,7 +2007,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	//							part_imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
 	//						else
 	//							part_imp_match_init_strict( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
-							Falign_localhom( mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, localhomshrink, &impmatch, gapmap1, gapmap2, NULL, 0, NULL );
+							Falign_localhom( NULL, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatch, gapmap1, gapmap2, NULL, 0, NULL );
 	//						fprintf( stderr, "##### impmatch = %f\n", impmatch );
 						}
 						else
